@@ -66,7 +66,7 @@ class AWSVaultMigrate(object):
                         self.credentials.remove_section(profile_name)
 
         with open(AWS_CREDENTIAL_PATH, 'w') as credentialfile:
-            self.redentials.write(credentialfile)
+            self.credentials.write(credentialfile)
 
         pass
 
